@@ -5,7 +5,7 @@ package Mojolicious::Plugin::YamlConfig;
 
 use base 'Mojolicious::Plugin::JSONConfig';
 
-our $VERSION = '0.2.3';
+our $VERSION = '0.2.4';
 
 sub register {
     my ( $self, $app, $conf ) = @_;
@@ -69,13 +69,9 @@ Mojolicious::Plugin::YamlConfig - YAML Configuration Plugin
     # Mojolicious::Lite
     plugin 'yaml_config';
 
-    # Reads myapp.yaml by default and puts the parsed version into the stash
-    my $config = $self->stash('config');
-
     # Everything can be customized with options
     plugin yaml_config => {
         file      => '/etc/myapp.conf',
-        stash_key => 'conf',
         class     => 'YAML::XS'
     };
 
